﻿Public Class Library

    ''' <summary>
    ''' Gets or sets the library code. This must correspond to a key in the GlobalMembers.Libraries dictionary!
    ''' </summary>
    ''' <remarks></remarks>
    Public Property Code As String

    ''' <summary>
    ''' Gets or sets the name of the library.
    ''' </summary>
    ''' <remarks></remarks>
    Public Property Name As String

    ''' <summary>
    ''' Gets or sets the list of books (IDs) contained within the library. 
    ''' Each value should correspond to a key in the GlobalMembers.Books dictionary.
    ''' </summary>
    ''' <remarks></remarks>
    Public Property Books As New HashSet(Of String)

    ''' <summary>
    ''' Gets or sets the list of non-book media (IDs) contained within the library. 
    ''' Each value should correspond to a key in the GlobalMembers.NonBookMedia dictionary.
    ''' </summary>
    ''' <remarks></remarks>
    Public Property NonBookMedia As New HashSet(Of String)

    ''' <summary>
    ''' Gets the display name of the library.
    ''' </summary>
    ''' <remarks></remarks>
    Public ReadOnly Property DisplayName As String
        Get
            'The text to display in for example a ListBox.
            Return Me.Name & " --- " & Me.Code
        End Get
    End Property

    ''' <summary>
    ''' Initializes a new instance of the Library class.
    ''' </summary>
    ''' <param name="Name">The name of the library.</param>
    ''' <param name="Code">The library code. This must correspond to a key in the GlobalMembers.Libraries dictionary!</param>
    ''' <remarks></remarks>
    Public Sub New(ByVal Name As String, ByVal Code As String)
        'Constructor. Called whenever we write "New Library(...)".
        Me.Name = Name
        Me.Code = Code
    End Sub
End Class
