﻿Public Class frmAssociationScreen

    Private Sub frmAssociationScreen_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load
        'Libraries.
        lstLibraries.DisplayMember = "DisplayName"

        'Books.
        lstAllBooks.DisplayMember = "DisplayName"
        lstBooksCurrLib.DisplayMember = "DisplayName"

        'Media.
        lstAllMedia.DisplayMember = "DisplayName"
        lstMediaCurrLib.DisplayMember = "DisplayName"

        'Refresh ListBoxes.
        populatelstLibrary()
        populatelstBooks()
        populatelstBookMedia()
        populatelstBooksCurrLib()
        populatelstMediaCurrLib()
    End Sub

    Sub populatelstLibrary()
        lstLibraries.Items.Clear()

        For Each library In Libraries
            lstLibraries.Items.Add(library.Value)
        Next
    End Sub

    Sub populatelstBooks()
        lstAllBooks.Items.Clear()

        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        For Each book In Books

            'Add all books that are NOT already in the library.
            'Check the book's dictionary key against the values in Library.Books.
            If Not selectedLibrary.Books.Contains(book.Key) Then
                lstAllBooks.Items.Add(book.Value)
            End If

        Next
    End Sub

    Sub populatelstBookMedia()
        lstAllMedia.Items.Clear()

        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        For Each bookMedia In NonBookMedia

            'Add all media that is NOT already in the library.
            'Check the media's dictionary key against the values in Library.NonBookMedia.
            If Not selectedLibrary.NonBookMedia.Contains(bookMedia.Key) Then
                lstAllMedia.Items.Add(bookMedia.Value)
            End If

        Next
    End Sub

    Sub populatelstBooksCurrLib()
        lstBooksCurrLib.Items.Clear()

        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Iterate all book IDs in the library.
        For Each ID In selectedLibrary.Books

            'Get the respective book from our dictionary (if the book doesn't exist it will be ignored).
            Dim book As Book = Nothing
            If Books.TryGetValue(ID, book) Then

                'Add the book to our ListBox.
                lstBooksCurrLib.Items.Add(book)

            End If

        Next
    End Sub

    Sub populatelstMediaCurrLib()
        lstMediaCurrLib.Items.Clear()

        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Iterate all media IDs in the library.
        For Each ID In selectedLibrary.NonBookMedia

            'Get the respective media from our dictionary (if the media doesn't exist it will be ignored).
            Dim media As Media = Nothing
            If NonBookMedia.TryGetValue(ID, Media) Then

                'Add the media to our ListBox.
                lstMediaCurrLib.Items.Add(media)

            End If

        Next
    End Sub

    Private Sub btnAddBook_Click(sender As System.Object, e As System.EventArgs) Handles btnAddBook.Click
        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Get the selected book.
        Dim selectedBook As Book = TryCast(lstAllBooks.SelectedItem, Book)

        'If no book is selected, do not continue.
        If selectedBook Is Nothing Then Return

        'Add the selected book to the library.
        'If we for some reason add a duplicate, HashSet.Add() will return False and no exception will be thrown, so we're good to go!
        selectedLibrary.Books.Add(selectedBook.ID)

        'Update lists.
        populatelstBooks()
        populatelstBooksCurrLib()
    End Sub

    Private Sub btnAddMedia_Click(sender As System.Object, e As System.EventArgs) Handles btnAddMedia.Click
        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Get the selected non-book media.
        Dim selectedMedia As Media = TryCast(lstAllMedia.SelectedItem, Media)

        'If no media is selected, do not continue.
        If selectedMedia Is Nothing Then Return

        'Add the selected media to the library.
        'If we for some reason add a duplicate, HashSet.Add() will return False and no exception will be thrown, so we're good to go!
        selectedLibrary.NonBookMedia.Add(selectedMedia.ID)

        'Update lists.
        populatelstBookMedia()
        populatelstMediaCurrLib()
    End Sub

    Private Sub btnRemoveBook_Click(sender As System.Object, e As System.EventArgs) Handles btnRemoveBook.Click
        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Get the selected book.
        Dim selectedBook As Book = TryCast(lstBooksCurrLib.SelectedItem, Book)

        'If no book is selected, do not continue.
        If selectedBook Is Nothing Then Return

        'Remove the selected book from the library.
        selectedLibrary.Books.Remove(selectedBook.ID)

        'Update lists.
        populatelstBooks()
        populatelstBooksCurrLib()
    End Sub

    Private Sub btnRemoveMedia_Click(sender As System.Object, e As System.EventArgs) Handles btnRemoveMedia.Click
        'Get the selected library.
        Dim selectedLibrary As Library = TryCast(lstLibraries.SelectedItem, Library)

        'If no library is selected, do not continue.
        If selectedLibrary Is Nothing Then Return

        'Get the selected non-book media.
        Dim selectedMedia As Media = TryCast(lstMediaCurrLib.SelectedItem, Media)

        'If no media is selected, do not continue.
        If selectedMedia Is Nothing Then Return

        'Remove the selected media from the library.
        selectedLibrary.NonBookMedia.Remove(selectedMedia.ID)

        'Update lists.
        populatelstBookMedia()
        populatelstMediaCurrLib()
    End Sub

    Private Sub lstLibraries_SelectedIndexChanged(sender As System.Object, e As System.EventArgs) Handles lstLibraries.SelectedIndexChanged
        populatelstBooks()
        populatelstBookMedia()
        populatelstBooksCurrLib()
        populatelstMediaCurrLib()
    End Sub
End Class